AgentCtx

Struct AgentCtx 

pub struct AgentCtx {
    pub base: BaseCtx,
    pub label: String,
    pub model: Model,
    /* private fields */
}
Context for agent operations, providing access to models, tools, and other agents.

Fields

base: BaseCtx

Base context providing fundamental operations.

label: String

Label of the agent.

model: Model

Default AI model instance for completions.

Implementations

Source

impl AgentCtx

pub fn child( &self, agent_name: &str, agent_label: &str, ) -> Result<Self, BoxError>

Creates a child context for a specific agent.

Arguments
  • agent_name - Name of the agent to create context for.
pub fn child_base(&self, tool_name: &str) -> Result<BaseCtx, BoxError>

Creates a child base context for a specific tool.

Arguments
  • tool_name - Name of the tool to create context for.
pub fn with_caller(&self, caller: Principal) -> Self

Clones the context with a new caller principal.

pub fn completion_iter( self, req: CompletionRequest, resources: Vec<Resource>, ) -> CompletionRunner

Creates a completion runner for iterative processing of completion requests.

pub fn completion_stream( self, req: CompletionRequest, resources: Vec<Resource>, ) -> CompletionStream

Creates a completion stream for processing of completion requests.