pub struct RemoteEngines {
pub engines: BTreeMap<String, EngineCard>,
}Expand description
Collection of remote engines.
Fields
engines: BTreeMap<String, EngineCard>Registered engine cards keyed by their lowercase handle.
Implementations
Sourceimpl RemoteEngines
impl RemoteEngines
Sourcepub async fn register(
&mut self,
ctx: impl HttpFeatures,
args: RemoteEngineArgs,
) -> Result<(), BoxError>
pub async fn register( &mut self, ctx: impl HttpFeatures, args: RemoteEngineArgs, ) -> Result<(), BoxError>
Registers a remote engine with the given arguments.
Sourcepub fn get_tool_endpoint(
&self,
name: &str,
) -> Option<(Principal, String, String)>
pub fn get_tool_endpoint( &self, name: &str, ) -> Option<(Principal, String, String)>
Retrieves a remote tool endpoint and name from a prefixed name.
Sourcepub fn get_agent_endpoint(
&self,
name: &str,
) -> Option<(Principal, String, String)>
pub fn get_agent_endpoint( &self, name: &str, ) -> Option<(Principal, String, String)>
Retrieves a remote agent endpoint and name from a prefixed name.
Sourcepub fn get_id_by_endpoint(&self, endpoint: &str) -> Option<Principal>
pub fn get_id_by_endpoint(&self, endpoint: &str) -> Option<Principal>
Retrieves a remote engine ID by endpoint.
Sourcepub fn get_endpoint_by_id(&self, id: &Principal) -> Option<String>
pub fn get_endpoint_by_id(&self, id: &Principal) -> Option<String>
Retrieves a remote engine endpoint by ID.
Sourcepub fn tool_definitions(
&self,
endpoint: Option<&str>,
names: Option<&[String]>,
) -> Vec<FunctionDefinition>
pub fn tool_definitions( &self, endpoint: Option<&str>, names: Option<&[String]>, ) -> Vec<FunctionDefinition>
Sourcepub fn select_tool_resources(
&self,
prefixed_name: &str,
resources: &mut Vec<Resource>,
) -> Vec<Resource>
pub fn select_tool_resources( &self, prefixed_name: &str, resources: &mut Vec<Resource>, ) -> Vec<Resource>
Extracts resources from the provided list based on the tool’s supported tags.
Sourcepub fn agent_definitions(
&self,
endpoint: Option<&str>,
names: Option<&[String]>,
) -> Vec<FunctionDefinition>
pub fn agent_definitions( &self, endpoint: Option<&str>, names: Option<&[String]>, ) -> Vec<FunctionDefinition>