pub async fn atomic_write_file(
target_path: &Path,
data: &[u8],
existing_permissions: Option<&Permissions>,
) -> Result<(), BoxError>Expand description
Atomically writes data to a file by first writing to a temporary file and then renaming it into place.