WriteFileTool

Struct WriteFileTool 

pub struct WriteFileTool { /* private fields */ }

Implementations

Source

impl WriteFileTool

pub const NAME: &'static str = "write_file"

Tool name used for registration and function definition.

pub fn new(workspace: PathBuf) -> Self

Create a new WriteFileTool with the default workspace directory. You can add workspace directories for each call by including workspace or workspaces in the tool call’s context meta extra.

pub fn with_workspaces<I>(workspaces: I) -> Self
where I: IntoIterator<Item = PathBuf>,

Create a new WriteFileTool with the default workspace directories. Context meta workspaces take precedence over these defaults at call time.

pub fn with_description(self, description: String) -> Self