Module management

Module management 

Engine visibility and caller management policies.

Management policies decide which principals can administer an engine and who can access exported agents and tools. The default BaseManagement policy makes engines private to the controller and explicit managers.

Structs

BaseManagement
Basic principal-list management policy for an engine.

Enums

Visibility
Engine visibility for exported agents and tools.

Statics

SYSTEM_PATH
Root cache and storage namespace reserved for engine system data.

Traits

Management
Authorization policy used by Engine.