pub enum Visibility {
Private = 0,
Protected = 1,
Public = 2,
}Expand description
Engine visibility for exported agents and tools.
Variants
Private = 0
Only the controller and managers can access the engine.
Protected = 1
Managers can access the engine; non-manager access requires an external policy to grant permission before execution.
Public = 2
Any caller, including anonymous callers, can access exported functions.