pub enum MemoryToolArgs {
GetResource {
_id: u64,
conversation: u64,
},
GetConversation {
_id: u64,
},
GetConversationDelta {
_id: u64,
messages_offset: usize,
artifacts_offset: usize,
},
StopConversation {
_id: u64,
},
SteerConversation {
_id: u64,
message: String,
},
FollowUpConversation {
_id: u64,
message: String,
},
DeleteConversation {
_id: u64,
},
ListPrevConversations {
cursor: Option<String>,
limit: Option<usize>,
},
SearchConversations {
query: String,
limit: Option<usize>,
},
}Expand description
Arguments for “memory_api” tool
Variants
GetResource
Get one resource from a conversation owned by the caller.
Fields
GetConversation
Get a conversation by ID
GetConversationDelta
Get a conversation delta by message and artifact offsets.
Fields
StopConversation
Stop an in-progress conversation.
SteerConversation
Interrupt a conversation with a steering message.
Fields
FollowUpConversation
Queue a follow-up message for the next safe turn.
Fields
DeleteConversation
Delete a conversation owned by the caller.
ListPrevConversations
List previous conversations
Fields
SearchConversations
Search conversations