pub struct ConversationDelta {
pub _id: u64,
pub messages: Vec<Json>,
pub artifacts: Vec<Resource>,
pub status: ConversationStatus,
pub usage: Usage,
pub failed_reason: Option<String>,
pub updated_at: u64,
pub child: Option<u64>,
}Expand description
A delta of a conversation since a given offset, used for incremental fetching of conversation messages.
Fields
_id: u64Conversation ID.
messages: Vec<Json>The new messages since the given offset. The offset is determined by the client and is not stored in the database. It is used to support incremental fetching of conversation messages.
artifacts: Vec<Resource>New artifacts since the requested offset.
status: ConversationStatusCurrent lifecycle status.
usage: UsageAccumulated usage at the time the delta was read.
failed_reason: Option<String>Failure reason when the conversation failed.
updated_at: u64Last update timestamp in milliseconds.
child: Option<u64>Child continuation conversation ID, when present.