pub struct AgentCtx {
pub base: BaseCtx,
pub label: String,
pub model: Model,
/* private fields */
}Expand description
Context for agent operations, providing access to models, tools, and other agents.
Fields
base: BaseCtxBase context providing fundamental operations.
label: StringLabel of the agent.
model: ModelDefault AI model instance for completions.
Implementations
Sourceimpl AgentCtx
impl AgentCtx
Sourcepub fn child(
&self,
agent_name: &str,
agent_label: &str,
) -> Result<Self, BoxError>
pub fn child( &self, agent_name: &str, agent_label: &str, ) -> Result<Self, BoxError>
Creates a child context for a specific agent.
Arguments
agent_name- Name of the agent to create context for.
Sourcepub fn child_base(&self, tool_name: &str) -> Result<BaseCtx, BoxError>
pub fn child_base(&self, tool_name: &str) -> Result<BaseCtx, BoxError>
Creates a child base context for a specific tool.
Arguments
tool_name- Name of the tool to create context for.
Sourcepub fn with_caller(&self, caller: Principal) -> Self
pub fn with_caller(&self, caller: Principal) -> Self
Clones the context with a new caller principal.
Sourcepub fn completion_iter(
self,
req: CompletionRequest,
resources: Vec<Resource>,
) -> CompletionRunner
pub fn completion_iter( self, req: CompletionRequest, resources: Vec<Resource>, ) -> CompletionRunner
Creates a completion runner for iterative processing of completion requests.
Sourcepub fn completion_stream(
self,
req: CompletionRequest,
resources: Vec<Resource>,
) -> CompletionStream
pub fn completion_stream( self, req: CompletionRequest, resources: Vec<Resource>, ) -> CompletionStream
Creates a completion stream for processing of completion requests.