Module memory

Module memory 

Persistent memory tools and conversation storage.

This module stores conversations, resources, artifacts, and memory-management commands for agents. Conversation metadata is stored in AndaDB collections with BTree and BM25 indexes, while higher-level memory operations are exposed through KIP (Knowledge Interaction Protocol) tools backed by the Cognitive Nexus.

Structs

Conversation
Conversation record stored in the memory database.
ConversationDelta
A delta of a conversation since a given offset, used for incremental fetching of conversation messages.
ConversationRef
ConversationState
Conversations
GetResourceContentArgs
Arguments for “get_resource_content” tool
GetResourceContentTool
ListConversationsArgs
Arguments for “list_previous_conversations” tool
ListConversationsTool
MemoryManagement
MemoryReadonly
A read-only version of the KIP tool for memory management, which does not allow any modifications to the memory and is safe to use for retrieval operations.
MemoryTool
A tool for conversation API
PrunedMessage
SearchConversationsArgs
Arguments for “search_conversations” tool
SearchConversationsTool

Enums

ConversationStatus
MemoryToolArgs
Arguments for “memory_api” tool

Statics

FUNCTION_DEFINITION