Persistent memory tools and conversation storage.
This module stores conversations, resources, artifacts, and memory-management commands for agents. Conversation metadata is stored in AndaDB collections with BTree and BM25 indexes, while higher-level memory operations are exposed through KIP (Knowledge Interaction Protocol) tools backed by the Cognitive Nexus.
Structs
- Conversation
- Conversation record stored in the memory database.
- Conversation
Delta - A delta of a conversation since a given offset, used for incremental fetching of conversation messages.
- Conversation
Ref - Conversation
State - Conversations
- GetResource
Content Args - Arguments for “get_resource_content” tool
- GetResource
Content Tool - List
Conversations Args - Arguments for “list_previous_conversations” tool
- List
Conversations Tool - Memory
Management - Memory
Readonly - A read-only version of the KIP tool for memory management, which does not allow any modifications to the memory and is safe to use for retrieval operations.
- Memory
Tool - A tool for conversation API
- Pruned
Message - Search
Conversations Args - Arguments for “search_conversations” tool
- Search
Conversations Tool
Enums
- Conversation
Status - Memory
Tool Args - Arguments for “memory_api” tool