Module memory

Module memory 

Structs

Conversation
A conversation between an agent and the system, stored in the database for memory management. Version 2
ConversationRef
ConversationState
GetResourceContentArgs
Arguments for “get_resource_content” tool
GetResourceContentTool
KIPLogs
ListConversationsArgs
Arguments for “list_prev_conversations” tool
ListConversationsTool
MemoryManagement
MemoryReadonly
A read-only version of the KIP tool for memory management, which does not allow any modifications to the memory and is safe to use for retrieval operations.
MemoryTool
A tool for conversation API
SearchConversationsArgs
Arguments for “search_conversations” tool
SearchConversationsTool

Enums

ConversationStatus
MemoryToolArgs
Arguments for “memory_api” tool

Statics

FUNCTION_DEFINITION