Structs
- Conversation
- A conversation between an agent and the system, stored in the database for memory management. Version 2
- Conversation
Ref - Conversation
State - GetResource
Content Args - Arguments for “get_resource_content” tool
- GetResource
Content Tool - KIPLogs
- List
Conversations Args - Arguments for “list_prev_conversations” tool
- List
Conversations Tool - Memory
Management - Memory
Readonly - A read-only version of the KIP tool for memory management, which does not allow any modifications to the memory and is safe to use for retrieval operations.
- Memory
Tool - A tool for conversation API
- Search
Conversations Args - Arguments for “search_conversations” tool
- Search
Conversations Tool
Enums
- Conversation
Status - Memory
Tool Args - Arguments for “memory_api” tool