pub struct Conversation {
pub _id: u64,
pub user: Principal,
pub thread: Option<Xid>,
pub messages: Vec<Json>,
pub resources: Vec<Resource>,
pub artifacts: Vec<Resource>,
pub status: ConversationStatus,
pub failed_reason: Option<String>,
pub usage: Usage,
pub period: u64,
pub created_at: u64,
pub updated_at: u64,
}Fields
_id: u64The unique identifier for this resource in the Anda DB collection “conversation”.
user: Principalthread: Option<Xid>messages: Vec<Json>resources: Vec<Resource>The request resources used by the agent to process the conversation.
artifacts: Vec<Resource>A collection of artifacts generated by the agent during the execution of the task.
status: ConversationStatusThe state of the conversation.
failed_reason: Option<String>usage: UsageThe LLM usage statistics for the conversation.
period: u64The period when the conversation was created, in hours (timestamp / 3600 / 1000). It is used to index the conversation for faster retrieval by time.
created_at: u64The timestamp when the conversation was created, in milliseconds.
updated_at: u64The timestamp when the conversation was updated, in milliseconds.
Implementations
Sourceimpl Conversation
impl Conversation
pub fn schema() -> Result<Schema, SchemaError>
Sourceimpl Conversation
impl Conversation