pub struct Store { /* private fields */ }Expand description
Main storage interface combining object storage and vector search capabilities
In Anda Engine, the path parameter is derived from agents’ or tools’ name,
ensuring isolated object storage for each agent or tool.
Both VectorStore and Store use ObjectStore as their backend storage.
They can share the same storage instance while maintaining data isolation through path.
You can find various implementations of ObjectStore at:
https://github.com/apache/arrow-rs/tree/main/object_store
Alternatively, you can use IC-COSE’s
ObjectStore implementation, which stores data on the ICP blockchain.
Implementations
Sourceimpl Store
impl Store
pub fn new(store: Arc<dyn ObjectStore>) -> Self
Sourcepub async fn store_get(
&self,
namespace: &Path,
path: &Path,
) -> Result<(Bytes, ObjectMeta), BoxError>
pub async fn store_get( &self, namespace: &Path, path: &Path, ) -> Result<(Bytes, ObjectMeta), BoxError>
Retrieves data from storage at the specified path
Sourcepub async fn store_list(
&self,
namespace: &Path,
prefix: Option<&Path>,
offset: &Path,
) -> Result<Vec<ObjectMeta>, BoxError>
pub async fn store_list( &self, namespace: &Path, prefix: Option<&Path>, offset: &Path, ) -> Result<Vec<ObjectMeta>, BoxError>
Lists objects in storage with optional prefix and offset filters
Arguments
prefix- Optional path prefix to filter resultsoffset- Optional path to start listing from (exclude)
Sourcepub async fn store_put(
&self,
namespace: &Path,
path: &Path,
mode: PutMode,
val: Bytes,
) -> Result<PutResult, BoxError>
pub async fn store_put( &self, namespace: &Path, path: &Path, mode: PutMode, val: Bytes, ) -> Result<PutResult, BoxError>
Stores data at the specified path with a given write mode
Arguments
path- Target storage pathmode- Write mode (Create, Overwrite, etc.)val- Data to store as bytes